package com.chinaweal.aiccs.aiccs.statistic.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.chinaweal.aiccs.aiccs.statistic.entity.StatisticsResult;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 定时统计结果存储表 Mapper 接口
 * </p>
 *
 * @author chinaweal
 * @since 2020-08-05
 */
public interface StatisticsResultMapper extends BaseMapper<StatisticsResult> {

    /**
     * 查找最近的统计记录
     *
     * @param moduleTag 模块tag
     * @return 查询结果
     * @author lroyia
     * @since 2020年8月5日 16:25:31
     */
    StatisticsResult selectLatest(@Param("moduleTag") String moduleTag);

    List<Map<String, String>> staticAllRegionTsabnlist();

    List<Map<String, Integer>> staticAbnByYear();

    List<Map<String, Integer>> staticAbnByMonth();

    List<Map<String, Integer>> staticAbnByWeek();

    List<Map<String, String>> staticAbnByIn();

    List<Map<String, Integer>> staticAbnByOut();

    List<Map<String, String>> staticAllRegionTsserill();

    List<Map<String, Integer>> staticTsserillByYear();

    List<Map<String, Integer>> staticTsserillByIn();

    List<Map<String, String>> staticTsserillByOutRe();

    List<Map<String, String>> staticRevRegion();

    List<Map<String, Integer>> staticRevYear();

    List<Map<String, String>> staticLockRegion();

    List<Map<String, Integer>> staticLockType();

    List<Map<String, String>> staticFraudRegion();

    List<Map<String, Integer>> staticFraudYear();

    List<Map<String, Integer>> staticFraudType();

    List<Map<String, String>> staticTsusualinspectRegion();

    List<Map<String, Integer>> staticTsusualinspectType();
}
